@@ -15,15 +15,15 @@ import random
 import re
 import json
 import tarfile
-import glob
 from datetime import datetime
 from contextlib import contextmanager
 from io import StringIO
 import sys
 import numpy as np
 import datetime
-from collections import Iterable
+from collections import defaultdict
 from itertools import takewhile, repeat, islice
+import shutil
 
 
 @contextmanager
@@ -542,5 +542,47 @@ def untar_gz(tar_gz_file, out_dir="."):
     return out_dir
 
 
+def convert_seconds(seconds):
+    """Convert seconds into """
+    seconds_in_day = 86400
+    seconds_in_hr = 3600
+    seconds_in_min = 60
+    days = seconds // seconds_in_day
+    hrs = (seconds - (days*seconds_in_day)) // seconds_in_hr
+    mins = (seconds - (days*seconds_in_day) - (hrs*seconds_in_hr)) // seconds_in_min
+    secs = (seconds - (days*seconds_in_day) - (hrs*seconds_in_hr) - (mins*seconds_in_min)) // 1
+    return days, hrs, mins, secs
+
+
+class NestedDefaultDict(defaultdict):
+    """Create an infinitely deep default dictionary.
+
+    source: https://stackoverflow.com/questions/19189274/nested-defaultdict-of-defaultdict
+    """
+    def __init__(self):
+        super(NestedDefaultDict, self).__init__(NestedDefaultDict)
+
+    def __repr__(self):
+        return repr(dict(self))
+
+
+def concatenate_files(file_paths, output_file_path, remove_files=False):
+    """
+    Concatenate files (efficiently) given a list of file paths to a single file
+    :param file_paths: List of file path
+    :param output_file_path: Output file path name
+    :param remove_files: remove files that were concatenated together
+    :return: None
+    From Ryan Lorig-Roach
+    """
+    with open(output_file_path, 'ab+') as out_file:
+        for file_path in file_paths:
+            if os.path.exists(file_path):
+                with open(file_path, 'rb') as in_file:
+                    # 100MB per writing chunk to avoid reading big file into memory.
+                    shutil.copyfileobj(in_file, out_file, 1024*1024*100)
+                if remove_files:
+                    os.remove(file_path)
+
 if __name__ == '__main__':
     print("This is a library of python functions")
